from distutils.core import setup

setup(
        name            = 'grantster',
        version         = '1.1.0',
        py_modules      = ['grantster'],
        author          = 'Grant Rosario',
        author_email    = 'nothing@x.com',
        url             = 'http://www.hello.com',
        description     = 'A simple printer of nested lists',
    )
